==> anjuta-2.29.4.0.tar.gz: anjuta-2.29.4.0/libanjuta/interfaces/libanjuta-interfaces.h <==

/* Interfaces global include file */

#include "ianjuta-buildable.h"
#include "ianjuta-builder.h"
#include "ianjuta-debug-manager.h"
#include "ianjuta-debugger.h"
#include "ianjuta-debugger-breakpoint.h"
#include "ianjuta-debugger-instruction.h"
#include "ianjuta-debugger-memory.h"
#include "ianjuta-debugger-register.h"
#include "ianjuta-debugger-variable.h"
#include "ianjuta-document.h"
#include "ianjuta-document-manager.h"
#include "ianjuta-editor.h"
#include "ianjuta-editor-assist.h"
#include "ianjuta-editor-cell.h"
#include "ianjuta-editor-cell-style.h"
#include "ianjuta-editor-comment.h"
#include "ianjuta-editor-convert.h"
#include "ianjuta-editor-factory.h"
#include "ianjuta-editor-folds.h"
#include "ianjuta-editor-goto.h"
#include "ianjuta-editor-hover.h"
#include "ianjuta-editor-language.h"
#include "ianjuta-editor-line-mode.h"
#include "ianjuta-editor-search.h"
#include "ianjuta-editor-selection.h"
#include "ianjuta-editor-tip.h"
#include "ianjuta-editor-view.h"
#include "ianjuta-editor-zoom.h"
#include "ianjuta-environment.h"
#include "ianjuta-file.h"
#include "ianjuta-file-loader.h"
#include "ianjuta-file-manager.h"
#include "ianjuta-file-savable.h"
#include "ianjuta-help.h"
#include "ianjuta-indicable.h"
#include "ianjuta-iterable.h"
#include "ianjuta-iterable-tree.h"
#include "ianjuta-language.h"
#include "ianjuta-language-support.h"
#include "ianjuta-loader.h"
#include "ianjuta-macro.h"
#include "ianjuta-markable.h"
#include "ianjuta-message-manager.h"
#include "ianjuta-message-view.h"
#include "ianjuta-plugin-factory.h"
#include "ianjuta-preferences.h"
#include "ianjuta-print.h"
#include "ianjuta-project-backend.h"
#include "ianjuta-project-manager.h"
#include "ianjuta-provider.h"
#include "ianjuta-stream.h"
#include "ianjuta-stream-loader.h"
#include "ianjuta-stream-savable.h"
#include "ianjuta-symbol.h"
#include "ianjuta-symbol-manager.h"
#include "ianjuta-terminal.h"
#include "ianjuta-todo.h"
#include "ianjuta-vcs.h"
#include "ianjuta-wizard.h"
#include "libanjuta-iface-marshallers.h"

==> anjuta-2.31.5.0.tar.gz: anjuta-2.31.5.0/libanjuta/interfaces/libanjuta-interfaces.h <==

/* Interfaces global include file */

#include "ianjuta-buildable.h"
#include "ianjuta-builder.h"
#include "ianjuta-debug-manager.h"
#include "ianjuta-debugger.h"
#include "ianjuta-debugger-breakpoint.h"
#include "ianjuta-debugger-instruction.h"
#include "ianjuta-debugger-memory.h"
#include "ianjuta-debugger-register.h"
#include "ianjuta-debugger-variable.h"
#include "ianjuta-document.h"
#include "ianjuta-document-manager.h"
#include "ianjuta-editor.h"
#include "ianjuta-editor-assist.h"
#include "ianjuta-editor-cell.h"
#include "ianjuta-editor-cell-style.h"
#include "ianjuta-editor-comment.h"
#include "ianjuta-editor-convert.h"
#include "ianjuta-editor-factory.h"
#include "ianjuta-editor-folds.h"
#include "ianjuta-editor-goto.h"
#include "ianjuta-editor-hover.h"
#include "ianjuta-editor-language.h"
#include "ianjuta-editor-line-mode.h"
#include "ianjuta-editor-search.h"
#include "ianjuta-editor-selection.h"
#include "ianjuta-editor-tip.h"
#include "ianjuta-editor-view.h"
#include "ianjuta-editor-zoom.h"
#include "ianjuta-environment.h"
#include "ianjuta-file.h"
#include "ianjuta-file-loader.h"
#include "ianjuta-file-manager.h"
#include "ianjuta-file-savable.h"
#include "ianjuta-help.h"
#include "ianjuta-indicable.h"
#include "ianjuta-iterable.h"
#include "ianjuta-iterable-tree.h"
#include "ianjuta-language.h"
#include "ianjuta-loader.h"
#include "ianjuta-macro.h"
#include "ianjuta-markable.h"
#include "ianjuta-message-manager.h"
#include "ianjuta-message-view.h"
#include "ianjuta-plugin-factory.h"
#include "ianjuta-preferences.h"
#include "ianjuta-print.h"
#include "ianjuta-project.h"
#include "ianjuta-project-backend.h"
#include "ianjuta-project-manager.h"
#include "ianjuta-provider.h"
#include "ianjuta-stream.h"
#include "ianjuta-stream-loader.h"
#include "ianjuta-stream-savable.h"
#include "ianjuta-symbol.h"
#include "ianjuta-symbol-manager.h"
#include "ianjuta-symbol-query.h"
#include "ianjuta-terminal.h"
#include "ianjuta-todo.h"
#include "ianjuta-vcs.h"
#include "ianjuta-wizard.h"
#include "libanjuta-iface-marshallers.h"
